@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.lswifi
@@ -16,15 +25,15 @@ import sys
 if sys.platform == "win32":
     pass
 else:
-    print(f"lswifi only works on win32... exiting...")
+    print("lswifi currently only works on win32 ... exiting ...")
     sys.exit(-1)
 
-# hard set no support for Python versions < 3.7
-if sys.version_info < (3, 7):
+# hard set no support for Python versions < 3.9
+if sys.version_info < (3, 9):
     print(
-        f"lswifi requires Python 3.7+. "
-        f"your active Python version is {platform.python_version()}. "
-        f"exiting..."
+        "lswifi requires Python 3.9+. \nyour active Python version is {0}.\nexiting...".format(
+            platform.python_version()
+        )
     )
     sys.exit(-1)
 
@@ -34,12 +43,12 @@ from lswifi.__version__ import __title__
 from lswifi.constants import APNAMEACKFILE, APNAMEJSONFILE
 
 
-def app_path() -> None:
+def app_path():
     appdata_path = os.path.join(os.getenv("LOCALAPPDATA"), __title__)  # type: ignore
     path_exists = os.path.isdir(appdata_path)
     if not path_exists:
         os.mkdir(appdata_path)
-    print(f"{appdata_path}")
+    print("{0}".format(appdata_path))
 
 
 def main():
@@ -48,21 +57,23 @@ def main():
     args = parser.parse_args()
     appsetup.setup_logger(args)
     log = logging.getLogger(__name__)
-    log.debug(f"args {args}")
-    log.debug(f"{sys.version}")
+    log.debug("args {0}".format(args))
+    log.debug("{0}".format(sys.version))
     if args.data_location:
         app_path()
         sys.exit()
     if args.apnames:
         is_apname_ack_stored = user_ack_apnames_disclaimer()
         log.debug(
-            f"is there a stored acknowledgement for caching apnames on local machine? {'Yes' if is_apname_ack_stored else 'No'}"
+            "is there a stored acknowledgement for caching apnames on local machine? {0}".format(
+                "Yes" if is_apname_ack_stored else "No"
+            )
         )
 
     app.run(args, storedack=is_apname_ack_stored)
 
 
-def user_ack_apnames_disclaimer() -> bool:
+def user_ack_apnames_disclaimer():
     """retrieve ack from user that BSSIDs and discovered apnames will be cached in appdata"""
     logger = logging.getLogger(__name__)
     if os.getenv("LOCALAPPDATA"):
@@ -88,8 +99,8 @@ def user_ack_apnames_disclaimer() -> bool:
             "  - Dwell time varies per channel and can be shorter than the standard beacon interval.\n\n"
             "Where?\n"
             "  - Cached data is stored and read from a JSON file on your device here:\n\n"
-            f"{apnames}\n"
         )
+        print("{0}".format(apnames))
         try:
             text = input(
                 "Please acknowledge storage and caching of AP names to enable feature (yes/no): "
@@ -102,15 +113,15 @@ def user_ack_apnames_disclaimer() -> bool:
                 pass  # we only need a placeholder file
             print(
                 "\nAP name caching is now enabled and we've recorded your response here: \n\n"
-                f"{ack}\n\n"
-                "If you'd like to disable this feature delete the file.\n"
             )
+            print("{0}\n\n".format(ack))
+            print("If you'd like to disable this feature delete the file.\n")
             return True
         else:
             return False
 
 
-def init() -> None:
+def init():
     """Handle main init."""
     if __name__ == "__main__":
         main()
