@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.client
@@ -286,7 +295,6 @@ def get_interface_info(args, iface) -> str:
                     outstr += f"    BSSID: {bssid}\n"
                     outstr += f"    BSS Type: {dot11BssType}\n"
                     outstr += f"    PHY: {dot11PhyType}\n"
-                    # out += "PH    Y Index: {}\n".format(uDot11PhyIndex)
                     outstr += f"    Signal Quality: {wlanSignalQuality}%\n"
                     outstr += f"    Rx Rate: {ulRxRate/1000} Mbps\n"
                     outstr += f"    Tx Rate: {ulTxRate/1000} Mbps\n"
@@ -308,19 +316,19 @@ def get_interface_info(args, iface) -> str:
                         if args.raw:
                             return f"{bssid}, {channel}"
                         else:
-                            return f"Interface: {iface.connection_name}, MAC: {iface.mac}, BSSID: {bssid}, CHANNEL: {channel}"
+                            return f"INTERFACE: {iface.connection_name}, MAC: {iface.mac}, BSSID: {bssid}, CHANNEL: {channel}"
 
                     if args.get_current_ap:
                         if args.raw:
                             return bssid
                         else:
-                            return f"Interface: {iface.connection_name}, MAC: {iface.mac}, BSSID: {bssid}"
+                            return f"INTERFACE: {iface.connection_name}, MAC: {iface.mac}, BSSID: {bssid}"
 
                     if args.get_current_channel:
                         if args.raw:
                             return channel
                         else:
-                            return f"Interface: {iface.connection_name}, MAC: {iface.mac}. Channel: {channel}"
+                            return f"INTERFACE: {iface.connection_name}, MAC: {iface.mac}, CHANNEL: {channel}"
         return outstr
     else:
         return ""
@@ -332,13 +340,15 @@ class Client(object):
             self.log = logging.getLogger(__name__)
             self.scan_finished = False
             self.data = None
-            now = datetime.datetime
             self.last_event = ""
-            self.last_scan_time_epoch = now.utcnow().timestamp()
-            self.last_scan_time_iso = (
-                now.now().astimezone().isoformat(timespec="milliseconds")
+            now = datetime.datetime.now()
+            nowutc = now.now(datetime.timezone.utc)
+            self.last_scan_time_epoch = now.timestamp()
+            self.last_scan_time_epoch_utc = nowutc.timestamp()
+            self.last_scan_time_iso = now.astimezone().isoformat(
+                timespec="milliseconds"
             )
-            self.last_scan_time_utc = now.utcnow()
+            self.last_scan_time_utc = nowutc
             self.args = args
             self.get_bssid_args = SimpleNamespace(
                 get_current_ap=True,
@@ -348,7 +358,7 @@ class Client(object):
                 supported=False,
                 is_bytes_arg=self.args.bytes,
             )
-            self.timeout_interval = 5.0
+            self.timeout_interval = 7.0
             self.client_handle = WLAN_API.WLAN.open_handle()
             # self.scan_timer = Timer(self.timeout_interval, self.scan_timeout)
             self.scan_timer = TimerEx(self.timeout_interval, self.scan_timeout)
@@ -524,16 +534,16 @@ class Client(object):
                 # if the list is updated, grab the results
                 if str(wlan_event).strip() == "scan_list_refresh":
                     self.log.debug(f"({self.mac}), start get_bss_list...")
-                    self.data = self.get_bss_list(
-                        self.iface, bytes=self.args.bytes
-                    )
+                    self.data = self.get_bss_list(self.iface, bytes=self.args.bytes)
                     self.scan_finished = True
-                    now = datetime.datetime
-                    self.last_scan_time_epoch = now.utcnow().timestamp()
-                    self.last_scan_time_iso = (
-                        now.now().astimezone().isoformat(timespec="milliseconds")
+                    now = datetime.datetime.now()
+                    nowutc = now.now(datetime.timezone.utc)
+                    self.last_scan_time_epoch = now.timestamp()
+                    self.last_scan_time_epoch_utc = nowutc.timestamp()
+                    self.last_scan_time_iso = now.astimezone().isoformat(
+                        timespec="milliseconds"
                     )
-                    self.last_scan_time_utc = now.utcnow()
+                    self.last_scan_time_utc = nowutc
                     self.log.debug(f"({self.mac}), finish get_bss_list...")
 
                 # if str(wlan_event).strip() == "network_available":
