@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.constants
@@ -12,18 +21,23 @@ from collections import namedtuple
 APNAMEACKFILE = "apnames.ack"
 APNAMEJSONFILE = "apnames.json"
 
+DECORS = ["~", "+", "=", "-"]
+DECORS_START = "-"
+DECORS_END = "-"
+DECORS_OUT = ()
+
 CIPHER_SUITE_DICT = {
     0: "Use group",  # "Use group cipher suite"
     1: "WEP-40",  # WEP
     2: "TKIP",  # WPA-Personal (TKIP is limited to 54 Mbps)
     3: "Reserved",
-    4: "AES",  # CCMP-128 WPA2-Enterprise 00-0F-AC:4 / WPA2-Personal 00-0F-AC:4
+    4: "CCMP-128",  # CCMP-128 WPA2-Enterprise 00-0F-AC:4 / WPA2-Personal 00-0F-AC:4
     5: "WEP-104",
     6: "BIP-CMAC-128",
-    7: "Group addressed traffic not allowed",
+    7: "Group not allowed",
     8: "GCMP-128",
     9: "GCMP-256",  # WPA3-Enterprise 00-0F-AC:9 / WPA3-Personal 00-0F-AC:9
-    10: "CMAC-256",
+    10: "CCMP-256",
     11: "BIP-GMAC-128",
     12: "BIP-GMAC-256",
     13: "BIP-CMAC-256",
@@ -33,29 +47,31 @@ CIPHER_SUITE_DICT = {
 
 AKM_SUITE_DICT = {
     0: "Reserved",
-    1: ".1X",  # WPA2-Enterprise aka 802.1X with SHA1
+    1: ".1X-SHA-1",  # WPA2-Enterprise aka 802.1X with SHA1
     2: "PSK",
-    3: "FT-.1X-SHA256",  # FT 802.1X with SHA256
+    3: "FT-.1X-SHA-256",  # FT 802.1X with SHA256
     4: "FT-PSK",
-    5: ".1X-SHA256",  # WPA3 - Enterprise aka 802.1X with SHA256
-    6: "PSK-SHA256",
-    7: "TDLS-SHA256",
+    5: ".1X-SHA-256",  # WPA3 - Enterprise aka 802.1X with SHA256
+    6: "PSK-SHA-256",
+    7: "TDLS-SHA-256",
     8: "SAE",  # SAE with p256 (HMAC-SHA-256)
     9: "FT-SAE",
     10: "APPeerKey",
-    11: ".1X-SuiteB-SHA256",
-    12: ".1X-SHA384",  # WPA3 - Enterprise 192-bit aka 802.1X with SHA384
-    13: "FT-.1X-SHA384",
-    14: "FILS-SHA256",
-    15: "FILS-SHA384",
-    16: "FT-FILS-SHA256",
-    17: "FT-FILS-SHA384",
+    11: ".1X-SuiteB-SHA-256",  # WPA3 - Enterprise SuiteB (pre-CNSA)
+    12: ".1X-CNSA-SHA-384",  # WPA3 - Enterprise 192-bit (CNSA) aka 802.1X with SHA384
+    13: "FT-.1X-SHA-384",
+    14: "FILS-SHA-256",
+    15: "FILS-SHA-384",
+    16: "FT-FILS-SHA-256",
+    17: "FT-FILS-SHA-384",
     18: "OWE",
-    19: "FT-PSK-SHA384",
-    20: "PSK-SHA384",
-    22: ".1X-SHA384-FT",
-    24: "SAE",  # SAE with p256 (HMAC-SHA-256), p384 (HMAC-SHA-384), or p521 (HMAC-SHA-521)
-    25: "FT-SAE",
+    19: "FT-PSK-SHA-384",
+    20: "PSK-SHA-384",
+    21: "PASN",
+    22: "FT-.1X-SHA-384",
+    23: ".1X-SHA-384",
+    24: "SAE-GDH",  # SAE with p256 (HMAC-SHA-256), p384 (HMAC-SHA-384), or p521 (HMAC-SHA-521) depending on DH group 19, 20, or 21 respectively
+    25: "FT-SAE-GDH",  # see comment on 24
 }
 
 INTERWORKING_NETWORK_TYPE = {
@@ -118,6 +134,7 @@ IE_DICT = {
     71: "Multiple BSSID",
     72: "20/40 BSS Coexistence",
     74: "Overlapping BSS Scan Parameters",
+    76: "Management MIC (MME)",
     84: "SSID List",
     107: "Interworking",
     108: "Advertisement Protocol",
@@ -154,10 +171,12 @@ VENDOR_SPECIFIC_DICT = {
     "00:50:F2": VENDOR("Microsoft", "Microsoft Corporation"),
     "00:03:7F": VENDOR("Atheros", "Atheros Communications Inc."),
     "00:10:18": VENDOR("Broadcom", "Broadcom"),
+    "8C:FD:F0": VENDOR("Qualcomm", "Qualcomm Inc."),
     "C8:3A:6B": VENDOR("Roku", "Roku, Inc"),
     "08:00:09": VENDOR("HP", "Hewlett Packard"),
     "00:17:F2": VENDOR("Apple", "Apple Inc."),
     "00:1D:0F": VENDOR("TP-Link", "TP-LINK Technologies Co., Ltd."),
+    "00:31:92": VENDOR("TP-Link", "TP-Link Corporation Limited"),
     "00:15:6D": VENDOR("Ubiquiti", "Ubiquiti Networks Inc."),
     "00:26:86": VENDOR("Quantenna", "Quantenna Communications, Inc."),
     "00:E0:4C": VENDOR("Realtek", "Realtek Semiconductor Corp."),
@@ -174,6 +193,13 @@ VENDOR_SPECIFIC_DICT = {
     "00:11:74": VENDOR("Mojo", "Mojo Networks, Inc."),
     "04:22:34": VENDOR("Wireless Standard Extensions", " Wireless Standard Extensions"),
     "18:FE:34": VENDOR("Espressif", "Espressif Inc."),
+    "00:50:43": VENDOR("Marvel", "Marvell Semiconductor Inc."),
+    "00:0F:7D": VENDOR("Xirrus", "Xirrus"),
+    "00:18:0A": VENDOR("Cisco Meraki", "Cisco Meraki"),
+    "00:20:91": VENDOR("J125, NSA", "J125, National Security Agency"),
+    "00:0C:42": VENDOR("Routerboard.com", "Routerboard.com"),
+    "00:1F:41": VENDOR("Ruckus", "Ruckus Wireless"),
+    "00:00:F0": VENDOR("Samsung", "Samsung Electronics Ltd"),
 }
 
 EXTENSION_IE_DICT = {
@@ -193,12 +219,16 @@ EXTENSION_IE_DICT = {
     58: "(58) Short SSID List",
     59: "(59) HE 6 GHz Band Capabilities",
     60: "(60) UL MU Power Capabilities",
-    106: "(106) EHT Operation",  # P802.11be_D2.3
-    107: "(107) Multi-Link",  # P802.11be_D2.3
-    108: "(108) EHT Capabilities",  # P802.11be_D2.3
-    109: "(109) TID-To-Link Mapping",  # P802.11be_D2.3
-    110: "(110) Multi-Link Traffic Indication",  # P802.11be_D2.3
-    113: "(113) QoS Characteristics",  # P802.11be_D2.3
+    106: "(106) EHT Operation",  # P802.11be_D6.0
+    107: "(107) Multi-Link",  # P802.11be_D6.0
+    108: "(108) EHT Capabilities",  # P802.11be_D6.0
+    109: "(109) TID-To-Link Mapping",  # P802.11be_D6.0
+    110: "(110) Multi-Link Traffic Indication",  # P802.11be_D6.0
+    113: "(113) QoS Characteristics",  # P802.11be_D6.0
+    133: "(133) MLO Link Info",  # P802.11be_D6.0
+    134: "(134) AID Bitmap",  # P802.11be_D6.0
+    135: "(135) Bandwidth Indication",  # P802.11be_D6.0
+    141: "(141) TWT Information Extension",  # P802.11be_D6.0
 }
 
 
@@ -391,6 +421,75 @@ _20MHZ_CHANNEL_LIST = {
     "7115": "233",
 }
 
+_2GHZ_5GHZ_20MHZ_CHANNEL_LIST = {
+    "2412": "1",
+    "2417": "2",
+    "2422": "3",
+    "2427": "4",
+    "2432": "5",
+    "2437": "6",
+    "2442": "7",
+    "2447": "8",
+    "2452": "9",
+    "2457": "10",
+    "2462": "11",
+    "2467": "12",
+    "2472": "13",
+    "2484": "14",
+    "5160": "32",
+    "5170": "34",
+    "5180": "36",
+    "5190": "38",
+    "5200": "40",
+    "5210": "42",
+    "5220": "44",
+    "5230": "46",
+    "5240": "48",
+    "5250": "50",
+    "5260": "52",
+    "5270": "54",
+    "5280": "56",
+    "5290": "58",
+    "5300": "60",
+    "5310": "62",
+    "5320": "64",
+    "5340": "68",
+    "5480": "96",
+    "5500": "100",
+    "5510": "102",
+    "5520": "104",
+    "5530": "106",
+    "5540": "108",
+    "5550": "110",
+    "5560": "112",
+    "5570": "114",
+    "5580": "116",
+    "5590": "118",
+    "5600": "120",
+    "5610": "122",
+    "5620": "124",
+    "5630": "126",
+    "5640": "128",
+    "5660": "132",
+    "5670": "134",
+    "5680": "136",
+    "5700": "140",
+    "5710": "142",
+    "5720": "144",
+    "5745": "149",
+    "5755": "151",
+    "5765": "153",
+    "5775": "155",
+    "5785": "157",
+    "5795": "159",
+    "5805": "161",
+    "5825": "165",
+    "5845": "169",
+    "5865": "173",
+    "5885": "177",
+    "5905": "181",
+}
+
 _6GHZ_20MHZ_CHANNEL_LIST = {
     "5955": "1",
     "5975": "5",
@@ -512,7 +611,7 @@ _6GHZ_160MHZ_CHANNEL_LIST = {
     "6985": "207",
 }
 
-# Based on P802.11be_D2.3
+# Based on P802.11be_D6.0 Annex E.1 Table E-4
 _6GHZ_320MHZ_CHANNEL_LIST = {
     "6105": "31",
     "6265": "63",
