@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.helpers
@@ -14,7 +23,11 @@ import re
 import sys
 from base64 import b64encode
 
-from lswifi.constants import _6GHZ_20MHZ_CHANNEL_LIST, _20MHZ_CHANNEL_LIST
+from lswifi.constants import (
+    _2GHZ_5GHZ_20MHZ_CHANNEL_LIST,
+    _6GHZ_20MHZ_CHANNEL_LIST,
+    _20MHZ_CHANNEL_LIST,
+)
 
 __control_chars = "".join(
     map(chr, itertools.chain(range(0x00, 0x20), range(0x7F, 0xA0)))
@@ -186,18 +199,19 @@ def is_six_band(frequency: str) -> bool:
     return False
 
 
-def get_channel_number_from_frequency(frequency):
+def get_channel_number_from_frequency(freq):
     """gets the 802.11 channel for a corresponding frequency
     in units of kilohertz (kHz). does not support FHSS."""
     try:
-        _frequency = frequency
-        if type(_frequency) == str:
-            _frequency = _frequency.replace(".", "", 1)
-            return _20MHZ_CHANNEL_LIST.get(_frequency, "Unknown")
+        if type(freq) == str:
+            freq = freq.replace(".", "", 1)
+            freq = _20MHZ_CHANNEL_LIST.get(freq, "--")
+            return freq
         else:
-            return _20MHZ_CHANNEL_LIST.get(str(_frequency), "Unknown")
+            freq = _20MHZ_CHANNEL_LIST.get(str(freq), "--")
+            return freq
     except KeyError:
-        return "Unknown"
+        return "--"
 
 
 def twos(val, bytes):
@@ -210,10 +224,10 @@ def twos(val, bytes):
 
 
 def get_6ghz_frequency_from_channel_number(channel_number: str) -> str:
-    """gets the center frequency for a corresponding channel
+    """gets the center frequency for a corresponding 6 GHz channel
 
     Args:
-        channel_number (int): 802.11 channel number
+        channel_number (int): 6 GHz 802.11 channel number
 
     Returns:
         str: frequency
@@ -224,6 +238,21 @@ def get_6ghz_frequency_from_channel_number(channel_number: str) -> str:
     return "Unknown"
 
 
+def get_2ghz5ghz_frequency_from_channel_number(channel_number: str) -> str:
+    """gets the center frequency for a corresponding 2.4 / 5 GHz GHz channel
+
+    Args:
+        channel_number (int): 2.4 / GHz 802.11 channel number
+
+    Returns:
+        str: frequency
+    """
+    for key, value in _2GHZ_5GHZ_20MHZ_CHANNEL_LIST.items():
+        if channel_number == value:
+            return key
+    return "Unknown"
+
+
 class Base64Encoder(json.JSONEncoder):
     """A Base64 encoder for JSON"""
 
