@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.rnr
@@ -9,10 +18,12 @@ schema definition for Reduced Neighbor Report (RNR IE 201)
 
 from collections import namedtuple
 
-from lswifi.helpers import get_6ghz_frequency_from_channel_number
+from lswifi.helpers import (
+    get_2ghz5ghz_frequency_from_channel_number,
+    get_6ghz_frequency_from_channel_number,
+)
 from lswifi.schemas.out import Header, OutObject, SubHeader
 
-# Declaring namedtuple()
 RNR = namedtuple(
     "RNR",
     [
@@ -31,6 +42,11 @@ RNR = namedtuple(
         "RNR_UPR_ACTIVE",
         "RNR_COLOCATED_AP",
         "RNR_TWENTY_MHZ_PSD",
+        "RNR_AP_MLD_ID",
+        "RNR_LINK_ID",
+        "RNR_BSS_PARAMS_CHANGE_COUNT",
+        "RNR_ALL_UPDATES_INCLUDED",
+        "RNR_DISABLED_LINK",
     ],
 )
 
@@ -38,8 +54,8 @@ RNR = namedtuple(
 class OOB_BSSID(OutObject):
     """Base class for Discovery BSSID Designation"""
 
-    def __init__(self, ssid=""):
-        self.value = ssid
+    def __init__(self, bssid=""):
+        self.value = bssid
         self.header = Header("BSSID")
         self.subheader = SubHeader("[MAC Address]")
 
@@ -146,8 +162,11 @@ class RNR_CHANNEL(OutObject):
 class RNR_FREQ(OutObject):
     """Base class for RNR Frequency Designation"""
 
-    def __init__(self, channel):
-        self.value = get_6ghz_frequency_from_channel_number(str(channel))
+    def __init__(self, channel, operating_class):
+        if int(operating_class) in (131, 132, 133, 134, 135):
+            self.value = get_6ghz_frequency_from_channel_number(str(channel))
+        else:
+            self.value = get_2ghz5ghz_frequency_from_channel_number(str(channel))
         self.header = Header("NEIGHBOR")
         self.subheader = SubHeader("FREQ.")
 
@@ -225,3 +244,63 @@ class RNR_COLOCATED_AP(OutObject):
 
     def __repr__(self):
         return f"OutObject({self.value},{self.header},{self.subheader})"
+
+
+class RNR_AP_MLD_ID(OutObject):
+    """Base class for MLD ID Designation"""
+
+    def __init__(self, mld_id):
+        self.value = mld_id if mld_id is not None else "--"
+        self.header = Header("AP MLD")
+        self.subheader = SubHeader("ID")
+
+    def __repr__(self):
+        return f"OutObject({self.value},{self.header},{self.subheader})"
+
+
+class RNR_LINK_ID(OutObject):
+    """Base class for Link ID Designation"""
+
+    def __init__(self, link_id):
+        self.value = link_id if link_id is not None else "--"
+        self.header = Header("LINK")
+        self.subheader = SubHeader("ID")
+
+    def __repr__(self):
+        return f"OutObject({self.value},{self.header},{self.subheader})"
+
+
+class RNR_BSS_PARAMS_CHANGE_COUNT(OutObject):
+    """Base class for BSS Parameters Change Count Designation"""
+
+    def __init__(self, change_count):
+        self.value = change_count if change_count is not None else "--"
+        self.header = Header("BSS PARAMS")
+        self.subheader = SubHeader("CHANGE COUNT")
+
+    def __repr__(self):
+        return f"OutObject({self.value},{self.header},{self.subheader})"
+
+
+class RNR_ALL_UPDATES_INCLUDED(OutObject):
+    """Base class for All Updates Included Designation"""
+
+    def __init__(self, all_updates):
+        self.value = "Yes" if all_updates else "--"
+        self.header = Header("ALL UPDATES")
+        self.subheader = SubHeader("INCLUDED")
+
+    def __repr__(self):
+        return f"OutObject({self.value},{self.header},{self.subheader})"
+
+
+class RNR_DISABLED_LINK(OutObject):
+    """Base class for Disabled Link Indication Designation"""
+
+    def __init__(self, disabled_link):
+        self.value = "Yes" if disabled_link else "--"
+        self.header = Header("DISABLED")
+        self.subheader = SubHeader("LINK")
+
+    def __repr__(self):
+        return f"OutObject({self.value},{self.header},{self.subheader})"
