@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.syslog
@@ -42,4 +51,7 @@ def message(message, level):
                     + ", Client: "
                     + message
                 )
-                SYSLOG_SOCKET.sendto(bytes(line_to_send, "utf-8"), (ip, 514))
+                try:
+                    SYSLOG_SOCKET.sendto(bytes(line_to_send, "utf-8"), (ip, 514))
+                except socket.error:
+                    pass
