@@ -1,4 +1,13 @@
 # -*- coding: utf-8 -*-
+#
+# lswifi - a CLI-centric Wi-Fi scanning tool for Windows
+# Copyright (c) 2025 Josh Schmelzle
+# SPDX-License-Identifier: BSD-3-Clause
+#  _              _  __ _
+# | |_____      _(_)/ _(_)
+# | / __\ \ /\ / / | |_| |
+# | \__ \\ V  V /| |  _| |
+# |_|___/ \_/\_/ |_|_| |_|
 
 """
 lswifi.wlanapi
@@ -9,13 +18,14 @@ mostly wrapper code around Native Wifi wlanapi.h
 
 import contextlib
 import logging
-import subprocess
 import sys
 import threading
+from collections import namedtuple
 from ctypes import (
     c_bool,
     c_byte,
     c_char,
+    c_char_p,
     c_long,
     c_ubyte,
     c_uint,
@@ -24,10 +34,11 @@ from ctypes import (
     c_ushort,
     c_void_p,
     c_wchar,
+    c_wchar_p,
+    cast,
+    create_string_buffer,
 )
 from enum import Enum
-from shutil import which
-from subprocess import SubprocessError, run
 
 from lswifi.guid import GUID
 
@@ -87,15 +98,111 @@ WLAN_REASON_CODE = DWORD
 ## (MAC) address: `typedef UCHAR DOT11_MAC_ADDRESS[6];`
 DOT11_MAC_ADDRESS = c_ubyte * 6
 
+# load wlanapi.dll into memory
+
 WLAN_API_EXISTS = True
 
-# load wlanapi.dll into memory
 try:
     WLAN_API = windll.LoadLibrary("wlanapi.dll")
 except OSError:
     WLAN_API_EXISTS = False
     print("!!! wlanapi.dll not foud !!!")
 
+# load iphlpapi.dll into memory
+
+IPHLP_API_EXISTS = True
+
+try:
+    IPHLP_API = windll.LoadLibrary("iphlpapi.dll")
+except OSError:
+    IPHLP_API_EXISTS = False
+    print("!!! iphlpapi.dll not foud !!!")
+
+MAX_ADAPTER_NAME_LENGTH = 256
+MAX_ADAPTER_DESCRIPTION_LENGTH = 128
+MAX_ADAPTER_ADDRESS_LENGTH = 8
+
+# IP_ADAPTER_ADDRESSES structure
+
+
+# Define IP_ADAPTER_ADDRESSES structure
+class IP_ADAPTER_ADDRESSES(Structure):
+    pass  # This will be dynamically extended
+
+
+LP_IP_ADAPTER_ADDRESSES = POINTER(IP_ADAPTER_ADDRESSES)
+
+IP_ADAPTER_ADDRESSES._fields_ = [
+    ("Length", DWORD),
+    ("IfIndex", DWORD),
+    ("Next", LP_IP_ADAPTER_ADDRESSES),
+    ("AdapterName", c_char_p),
+    ("FirstUnicastAddress", c_void_p),
+    ("FirstAnycastAddress", c_void_p),
+    ("FirstMulticastAddress", c_void_p),
+    ("FirstDnsServerAddress", c_void_p),
+    ("DnsSuffix", c_wchar_p),
+    ("Description", c_wchar_p),
+    ("FriendlyName", c_wchar_p),
+    ("PhysicalAddress", c_ubyte * MAX_ADAPTER_ADDRESS_LENGTH),
+    ("PhysicalAddressLength", DWORD),
+    ("Flags", DWORD),
+    ("Mtu", DWORD),
+    ("IfType", DWORD),
+    ("OperStatus", DWORD),
+    ("Ipv6IfIndex", DWORD),
+    ("ZoneIndices", DWORD * 16),
+    ("FirstPrefix", c_void_p),
+]
+
+NetworkAdapter = namedtuple(
+    "NetworkAdapter", ["mac_address", "description", "friendly_name"]
+)
+
+
+def get_adapter_infos_by_guid(interface_guid):
+    # Call with 0 size to get required buffer size first
+    buffer_size = c_ulong(0)
+    result = IPHLP_API.GetAdaptersAddresses(
+        0, 0, None, None, byref(buffer_size)  # Family  # Flags  # Reserved  # Buffer
+    )
+
+    adapter_addresses = create_string_buffer(buffer_size.value)
+    result = IPHLP_API.GetAdaptersAddresses(
+        0,  # Family (0 = unspecified, returns both IPv4 and IPv6)
+        0,  # Flags
+        None,  # Reserved
+        byref(adapter_addresses),
+        byref(buffer_size),
+    )
+
+    if result != SystemErrorCodes.ERROR_SUCCESS.value:
+        raise RuntimeError(
+            f"Failed to retrieve adapter addresses, error code: {result}"
+        )
+
+    adapter = cast(adapter_addresses, POINTER(IP_ADAPTER_ADDRESSES))
+
+    while adapter:
+        # Convert adapter name to GUID format and compare
+        adapter_name = adapter.contents.AdapterName.decode()
+        guid_str = f"{adapter_name}"
+        if guid_str.lower() == str(interface_guid).lower():
+            mac_address = adapter.contents.PhysicalAddress
+            mac_length = adapter.contents.PhysicalAddressLength
+            return NetworkAdapter(
+                mac_address=":".join(
+                    f"{mac_address[i]:02X}" for i in range(mac_length)
+                ),
+                description=adapter.contents.Description,
+                friendly_name=adapter.contents.FriendlyName,
+            )
+
+        adapter = adapter.contents.Next
+
+    # raise ValueError("GUID not found among physical adapters")
+
+
 # DOT11_AUTH_ALGORITHM enumeration
 
 """ The DOT11_AUTH_ALGORITHM enumerated type defines a wireless LAN 
@@ -901,46 +1008,16 @@ class WirelessInterface(object):
         self.guid_string = str(wlan_iface_info.InterfaceGuid)
         self.state = wlan_iface_info.isState
         self.state_string = WLAN_INTERFACE_STATE_DICT.get(self.state, 0)
-        self.mac = "unknown"
+        adapter_info = get_adapter_infos_by_guid(self.guid_string)
         self.connection_name = "unknown"
-        self.map_guid_to_mac_and_connection_name(self.guid, self.description)
-
-    def map_guid_to_mac_and_connection_name(self, guid, description) -> None:
-        if which("getmac.exe"):
-            guid = str(guid)[1:-1]  # remove { } around guid
-            exe = (
-                'getmac.exe /FO "CSV" /V'  # use getmac.exe to map interface guid to mac
-            )
-            cmd = f"{exe}"
-            try:
-                output = run(
-                    cmd,
-                    stderr=subprocess.STDOUT,
-                    stdout=subprocess.PIPE,
-                    encoding="utf-8",
-                    errors="ignore",
-                )
-                mac = ""
-                self.log.debug(
-                    "checking output from '%s' to do a lookup on given guid for matching MAC and connection name",
-                    exe,
-                )
-                for line in output.stdout.strip().splitlines():
-                    if guid in line or description in line:
-                        connection = line.split(",")
-                        mac = connection[2].replace('"', "")
-                        self.mac = mac.lower().replace("-", ":")
-                        self.connection_name = connection[0].replace('"', "")
-                        self.log.debug(
-                            f"guid {guid} maps to {self.mac} and {self.connection_name}"
-                        )
-                        break
-            except SubprocessError as error:
-                raise error
-        else:
-            self.log.warn(
-                f"Unable to find getmac.exe to map {self.guid} to a physical address"
-            )
+        self.description = "unknown"
+        self.mac = "unknown"
+        if adapter_info:
+            self.mac = adapter_info.mac_address
+            if self.mac:
+                self.mac = self.mac.lower()
+            self.connection_name = adapter_info.friendly_name
+            self.description = adapter_info.description
 
     def __str__(self):
         return f"Interface: {self.__dict__}"
@@ -1575,6 +1652,8 @@ class WLAN:
         interfaces available.
         """
         ifaces = {}
+        wlan_interfaces = None
+        handle = None
         try:
             threads = list()
             handle = WLAN.open_handle()
@@ -1610,8 +1689,10 @@ class WLAN:
         except Exception:
             raise
         finally:
-            WLAN.free_memory(wlan_interfaces)
-            WLAN.close_handle(handle)
+            if wlan_interfaces:
+                WLAN.free_memory(wlan_interfaces)
+            if handle:
+                WLAN.close_handle(handle)
         return ifaces
 
     @staticmethod
